pub struct Action { /* private fields */ }Expand description
This file initiates all the non-ui, background actions that are required to satisfy the OTA UX UI slides. In general some states cause a background task to be run which may produce one or more state machine events. Actions may reboot the device.
Implementations
Sourceimpl Action
impl Action
pub fn new( event_sender: EventSender, ota_manager: Arc<dyn OtaManager>, crash_reporter: Option<Rc<CrashReporter>>, ) -> Self