pub struct RebootImpl;Trait Implementations
Sourceimpl Default for RebootImpl
impl Default for RebootImpl
Sourcefn default() -> RebootImpl
fn default() -> RebootImpl
Returns the “default value” for a type. Read more
Sourceimpl RebootHandler for RebootImpl
impl RebootHandler for RebootImpl
Sourcefn reboot<'life0, 'async_trait>(
&'life0 self,
delay_seconds: Option<u64>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn reboot<'life0, 'async_trait>(
&'life0 self,
delay_seconds: Option<u64>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Request a reboot with optional delay in seconds. This is currently not cancellable and does not return an error result.
The caller will be responsible for handling which thread to schedule this request on.