pub trait RebootHandler {
// Required method
fn reboot<'life0, 'async_trait>(
&'life0 self,
delay_seconds: Option<u64>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Required Methods
Sourcefn reboot<'life0, 'async_trait>(
&'life0 self,
delay_seconds: Option<u64>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn reboot<'life0, 'async_trait>(
&'life0 self,
delay_seconds: Option<u64>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Request a reboot with optional delay in seconds. This is currently not cancellable and does not return an error result. The caller will be responsible for handling which thread to schedule this request on.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".